Index: openacs-4/packages/acs-kernel/sql/oracle/upgrade/upgrade-5.0d2-5.0d3.sql
===================================================================
RCS file: /usr/local/cvsroot/openacs-4/packages/acs-kernel/sql/oracle/upgrade/upgrade-5.0d2-5.0d3.sql,v
diff -u -r1.7 -r1.8
--- openacs-4/packages/acs-kernel/sql/oracle/upgrade/upgrade-5.0d2-5.0d3.sql	1 Oct 2003 11:23:06 -0000	1.7
+++ openacs-4/packages/acs-kernel/sql/oracle/upgrade/upgrade-5.0d2-5.0d3.sql	17 Oct 2003 08:42:53 -0000	1.8
@@ -27,26 +27,30 @@
                              constraint auth_authority_enabled_p_ck
                              check (enabled_p in ('t','f')),
     sort_order               integer not null,
     -- Id of the authentication service contract implementation
     -- Cannot reference acs_sc_impls table as it doesn't exist yet
     auth_impl_id             integer
                              constraint auth_authority_auth_impl_fk
                              references acs_objects(object_id),
-    -- Id of the password management service contact implementation
+    -- auth_password implementation
     pwd_impl_id              integer
                              constraint auth_authority_pwd_impl_fk
                              references acs_objects(object_id),
     forgotten_pwd_url        varchar2(4000),
     change_pwd_url           varchar2(4000),
-    -- Id of the registration service contract implementation
+    -- auth_registration implementation
     register_impl_id         integer
                              constraint auth_authority_reg_impl_fk
                              references acs_objects(object_id),
     register_url             varchar2(4000),
+    -- auth_user_info implementation
+    user_info_impl_id        integer
+                             constraint auth_authority_userinf_impl_fk
+                             references acs_objects(object_id),
     -- batch sync
-    -- Id of service contract getting batch sync doc
+    -- auth_sync_retrieve implementation
     get_doc_impl_id          integer references acs_objects(object_id),
-    -- Id of service contract processing batch sync doc
+    -- auth_sync_process implementation
     process_doc_impl_id      integer references acs_objects(object_id),
     batch_sync_enabled_p     char(1) default 'f' 
                              constraint auth_authority_bs_enabled_p_nn
@@ -88,6 +92,24 @@
 /
 show errors
 
+create table auth_driver_params(
+      authority_id    integer
+                      constraint auth_driver_params_aid_fk 
+                      references auth_authorities(authority_id)
+                      constraint auth_driver_params_aid_nn
+                      not null,
+      impl_id         integer
+                      constraint auth_driver_params_iid_fk
+                      -- Cannot reference acs_sc_impls table as it doesn't exist yet
+                      references acs_objects(object_id)
+                      constraint auth_driver_params_iid_nn
+                      not null,
+      key             varchar2(200),
+      value           clob,
+      constraint auth_driver_params_pk
+      primary key (authority_id, impl_id, key)
+);
+
 -- Create PLSQL package
 create or replace package authority
 as 
@@ -179,7 +201,7 @@
     return integer
     is
     begin
-        acs_object.delete(delete_authority_id);
+        acs_object.del(delete_authority_id);
 
         return 0;
     end del;
@@ -188,6 +210,7 @@
 /
 show errors
 
+
 -- Create the local authority
 declare
   v_authority_id integer;
@@ -27,26 +27,30 @@
                              check (enabled_p in ('t','f')),
     sort_order               integer not null,
-    -- Id of the authentication service contract implementation
-    -- Cannot reference acs_sc_impls table as it doesn't exist yet
+    -- auth_authentication implementation
+    -- (Cannot reference acs_sc_impls table as it doesn't exist yet)
     auth_impl_id             integer
                              constraint auth_authority_auth_impl_fk
Fisheye: Tag 1.4 refers to a dead (removed) revision in file `openacs-4/packages/acs-kernel/sql/oracle/upgrade/upgrade-5.0d3-5.0d4.sql'.
Fisheye: No comparison available.  Pass `N' to diff?
Index: openacs-4/packages/acs-kernel/sql/postgresql/upgrade/upgrade-5.0d2-5.0d3.sql
===================================================================
RCS file: /usr/local/cvsroot/openacs-4/packages/acs-kernel/sql/postgresql/upgrade/upgrade-5.0d2-5.0d3.sql,v
diff -u -r1.9 -r1.10
--- openacs-4/packages/acs-kernel/sql/postgresql/upgrade/upgrade-5.0d2-5.0d3.sql	1 Oct 2003 11:23:06 -0000	1.9
+++ openacs-4/packages/acs-kernel/sql/postgresql/upgrade/upgrade-5.0d2-5.0d3.sql	17 Oct 2003 08:42:53 -0000	1.10
@@ -25,26 +25,30 @@
                              constraint auth_authority_enabled_p_nn
                              not null,
     sort_order               integer not null,
     -- Id of the authentication service contract implementation
     -- Cannot reference acs_sc_impls table as it doesn't exist yet
     auth_impl_id             integer
                              constraint auth_authority_auth_impl_fk
                              references acs_objects(object_id),
-    -- Id of the password management service contact implementation
+    -- auth_password implementation
     pwd_impl_id              integer
                              constraint auth_authority_pwd_impl_fk
                              references acs_objects(object_id),
     forgotten_pwd_url        varchar(4000),
     change_pwd_url           varchar(4000),
-    -- Id of the registration service contract implementation
+    -- auth_registration implementation
     register_impl_id         integer
                              constraint auth_authority_reg_impl_fk
                              references acs_objects(object_id),
     register_url             varchar(4000),
+    -- auth_user_info implementation
+    user_info_impl_id        integer
+                             constraint auth_authority_userinf_impl_fk
+                             references acs_objects(object_id),
     -- batch sync
-    -- Id of service contract getting batch sync doc
+    -- auth_sync_retrieve implementation
     get_doc_impl_id          integer references acs_objects(object_id),
-    -- Id of service contract processing batch sync doc
+    -- auth_sync_process implementation
     process_doc_impl_id      integer references acs_objects(object_id),
     batch_sync_enabled_p     boolean default 'f'
                              constraint auth_authority_bs_enabled_p_nn
@@ -81,6 +85,24 @@
     null
 );
 
+create table auth_driver_params(
+      authority_id    integer
+                      constraint auth_driver_params_aid_fk 
+                      references auth_authorities(authority_id)
+                      constraint auth_driver_params_aid_nn
+                      not null,
+      impl_id         integer
+                      constraint auth_driver_params_iid_fk
+                      -- Cannot reference acs_sc_impls table as it doesn't exist yet
+                      references acs_objects(object_id)
+                      constraint auth_driver_params_iid_nn
+                      not null,
+      key             varchar(200),
+      value           text,
+      unique (authority_id, impl_id)
+);
+
+
 -- Create PLSQL functions
 create or replace function authority__new (
     integer, -- authority_id
@@ -25,26 +25,30 @@
                              not null,
     sort_order               integer not null,
-    -- Id of the authentication service contract implementation
-    -- Cannot reference acs_sc_impls table as it doesn't exist yet
+    -- auth_authentication implementation
+    -- (Cannot reference acs_sc_impls table as it doesn't exist yet)
     auth_impl_id             integer
                              constraint auth_authority_auth_impl_fk
Fisheye: Tag 1.4 refers to a dead (removed) revision in file `openacs-4/packages/acs-kernel/sql/postgresql/upgrade/upgrade-5.0d3-5.0d4.sql'.
Fisheye: No comparison available.  Pass `N' to diff?